# clear workspace
rm(list=ls())
#setwd('C:\\Users\\gcmzi\\Desktop\\PCA_2020\\K_tries')


library(lme4)
library(broom)
library(tidystats)
library(bestNormalize)
library(lme4)
library(car)
library(lme4)
library(mvtnorm)
library(AICcmodavg)
library(binom)
library(Hmisc)


###################################################################
# stan code for correlation
model_simple <- "
// Pearson Correlation
data { 
  int<lower=0> n;
  vector[2] x_obs[n];
}
parameters {
  vector[2] mu;
  vector<lower=0>[2] lambda;
  real<lower=-1,upper=1> r;
} 
transformed parameters {
  vector<lower=0>[2] sigma;
  cov_matrix[2] T;

  // Reparameterization
  sigma[1] = sqrt(lambda[1]);
  sigma[2] = sqrt(lambda[2]);
  T[1,1] = square(sigma[1]);
  T[1,2] = r * sigma[1] * sigma[2];
  T[2,1] = r * sigma[1] * sigma[2];
  T[2,2] = square(sigma[2]);
}
model {
  // Priors
  mu ~ normal(0, 10);
  lambda ~ normal(0,1);

  // Data
  x_obs ~ multi_normal(mu, T);
}"

###################################################################
# load packages
library(mvtnorm)
library(ellipse)
library(rstan)
citation(package = "rstan")
###################################################################
# generate data from multivatiate normal distribution
#data <- rmvnorm(100, mean=c(1,5),sigma=matrix(c(0.,0.8,0.8,3),nrow=2))

#data <- rmvnorm(100, mean=c(0.1,5),sigma=matrix(c(0.2,0.002,0.002,0.004),nrow=2))


logit <- function(x) log(x/(1-x))
inv_logit <- function(x) exp(x)/(1+exp(x))

all_data <- read.table(file="Trav_data_IMPUTED.txt", header=T)



###########################################################################
##############################################################################


act_subset <- which(all_data$HOST=="DOWN" & all_data$exposure=="Unexposed")

data <- cbind(logit(all_data$resistance[act_subset]-0.001), logit(all_data$dispersal[act_subset]+0.001))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2


# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

rr<-extract(samples)$r
d<-density(rr)


# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################




###################################################################

act_subset <- which(all_data$HOST=="DOWN" & all_data$exposure=="Exposed")

data <- cbind(logit(all_data$resistance[act_subset]-0.001), logit(all_data$dispersal[act_subset]+0.001))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2

# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################


rr2<-extract(samples)$r
d2<-density(rr2)
mean(rr)
mean(rr2)
dquant<-quantile(rr,p=c(.025,.975))
dquant2<-quantile(rr2,p=c(.025,.975))



##########################################################################

act_subset <- which(all_data$HOST=="UP" & all_data$exposure=="Unexposed")

data <- cbind(logit(all_data$resistance[act_subset]-0.001), logit(all_data$dispersal[act_subset]+0.001))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2


# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

rr<-extract(samples)$r
d<-density(rr)


# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

###################################################################

act_subset <- which(all_data$HOST=="UP" & all_data$exposure=="Exposed")

data <- cbind(logit(all_data$resistance[act_subset]-0.001), logit(all_data$dispersal[act_subset]+0.001))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2


# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

rr2<-extract(samples)$r
d2<-density(rr2)
mean(rr)
mean(rr2)
dquant<-quantile(rr,p=c(.025,.975))
dquant2<-quantile(rr2,p=c(.025,.975))

###################################






###################### r and K
act_subset <- which(all_data$HOST=="DOWN" & all_data$exposure=="Unexposed")

data <- cbind(log(all_data$N[act_subset]), log(all_data$r[act_subset]))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2

# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))


rr<-extract(samples)$r
d<-density(rr)



# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

###################################################################

act_subset <- which(all_data$HOST=="DOWN" & all_data$exposure=="Exposed")

data <- cbind(log(all_data$N[act_subset]), log(all_data$r[act_subset]))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2

# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

rr2<-extract(samples)$r
d2<-density(rr2)

mean(rr)
mean(rr2)
dquant<-quantile(rr,p=c(.025,.975))
dquant2<-quantile(rr2,p=c(.025,.975))




##########################################################################

act_subset <- which(all_data$HOST=="UP" & all_data$exposure=="Unexposed")

data <- cbind(log(all_data$N[act_subset]), log(all_data$r[act_subset]))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2

# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

rr<-extract(samples)$r
d<-density(rr)



# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))
###################################################################


###################################################################

act_subset <- which(all_data$HOST=="UP" & all_data$exposure=="Exposed")

data <- cbind(log(all_data$N[act_subset]), log(all_data$r[act_subset]))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2

# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################


rr2<-extract(samples)$r
d2<-density(rr2)
mean(rr)
mean(rr2)
dquant<-quantile(rr,p=c(.025,.975))
dquant2<-quantile(rr2,p=c(.025,.975))


###################################









###################### speed and tortuosity
act_subset <- which(all_data$HOST=="DOWN" & all_data$exposure=="Unexposed")

data <- cbind(log(all_data$tortuosity[act_subset]), log(all_data$speed[act_subset]))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2

# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))


rr<-extract(samples)$r
d<-density(rr)

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

###################################################################

act_subset <- which(all_data$HOST=="DOWN" & all_data$exposure=="Exposed")

data <- cbind(log(all_data$tortuosity[act_subset]), log(all_data$speed[act_subset]))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2

# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))


###################################################################


rr2<-extract(samples)$r
d2<-density(rr2)
median(rr)
median(rr2)
dquant<-quantile(rr,p=c(.025,.975))
dquant2<-quantile(rr2,p=c(.025,.975))


##########################################################################

act_subset <- which(all_data$HOST=="UP" & all_data$exposure=="Unexposed")

data <- cbind(log(all_data$tortuosity[act_subset]), log(all_data$speed[act_subset]))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2

# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

rr<-extract(samples)$r
d<-density(rr)


# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

###################################################################

act_subset <- which(all_data$HOST=="UP" & all_data$exposure=="Exposed")

data <- cbind(log(all_data$tortuosity[act_subset]), log(all_data$speed[act_subset]))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2

# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

rr2<-extract(samples)$r
d2<-density(rr2)
mean(rr)
mean(rr2)
dquant<-quantile(rr,p=c(.025,.975))
dquant2<-quantile(rr2,p=c(.025,.975))



###################################











################################### dispersal-tortuosity

act_subset <- which(all_data$HOST=="DOWN" & all_data$exposure=="Unexposed")

data <- cbind(log(all_data$tortuosity[act_subset]), logit(all_data$dispersal[act_subset]+0.001))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2


# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

rr<-extract(samples)$r
d<-density(rr)


# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################




###################################################################

act_subset <- which(all_data$HOST=="DOWN" & all_data$exposure=="Exposed")

data <- cbind(log(all_data$tortuosity[act_subset]), logit(all_data$dispersal[act_subset]+0.001))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2

# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################


rr2<-extract(samples)$r
d2<-density(rr2)
mean(rr)
mean(rr2)
dquant<-quantile(rr,p=c(.025,.975))
dquant2<-quantile(rr2,p=c(.025,.975))




##########################################################################

act_subset <- which(all_data$HOST=="UP" & all_data$exposure=="Unexposed")

data <- cbind(log(all_data$tortuosity[act_subset]), logit(all_data$dispersal[act_subset]+0.001))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2


# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

rr<-extract(samples)$r
d<-density(rr)


# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

###################################################################

act_subset <- which(all_data$HOST=="UP" & all_data$exposure=="Exposed")

data <- cbind(log(all_data$tortuosity[act_subset]), logit(all_data$dispersal[act_subset]+0.001))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2


# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

rr2<-extract(samples)$r
d2<-density(rr2)
mean(rr)
mean(rr2)
dquant<-quantile(rr,p=c(.025,.975))
dquant2<-quantile(rr2,p=c(.025,.975))



###################################





################################### dispersal-speed

act_subset <- which(all_data$HOST=="DOWN" & all_data$exposure=="Unexposed")

data <- cbind(logit(all_data$speed[act_subset]), logit(all_data$dispersal[act_subset]+0.001))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2


# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

rr<-extract(samples)$r
d<-density(rr)


# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################




###################################################################

act_subset <- which(all_data$HOST=="DOWN" & all_data$exposure=="Exposed")

data <- cbind(log(all_data$speed[act_subset]), logit(all_data$dispersal[act_subset]+0.001))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2

# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################


rr2<-extract(samples)$r
d2<-density(rr2)
mean(rr)
mean(rr2)
dquant<-quantile(rr,p=c(.025,.975))
dquant2<-quantile(rr2,p=c(.025,.975))




##########################################################################

act_subset <- which(all_data$HOST=="UP" & all_data$exposure=="Unexposed")

data <- cbind(log(all_data$speed[act_subset]), logit(all_data$dispersal[act_subset]+0.001))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2


# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

rr<-extract(samples)$r
d<-density(rr)


# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

###################################################################

act_subset <- which(all_data$HOST=="UP" & all_data$exposure=="Exposed")

data <- cbind(log(all_data$speed[act_subset]), logit(all_data$dispersal[act_subset]+0.001))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2


# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

rr2<-extract(samples)$r
d2<-density(rr2)
mean(rr)
mean(rr2)
dquant<-quantile(rr,p=c(.025,.975))
dquant2<-quantile(rr2,p=c(.025,.975))



###################################







################################### resistance-r0

act_subset <- which(all_data$HOST=="DOWN" & all_data$exposure=="Unexposed")

data <- cbind(logit(all_data$resistance[act_subset]-0.001), log(all_data$r[act_subset]))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2


# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

rr<-extract(samples)$r
d<-density(rr)


# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################




###################################################################

act_subset <- which(all_data$HOST=="DOWN" & all_data$exposure=="Exposed")

data <- cbind(logit(all_data$resistance[act_subset]-0.001), log(all_data$r[act_subset]))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2

# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################


rr2<-extract(samples)$r
d2<-density(rr2)
mean(rr)
mean(rr2)
dquant<-quantile(rr,p=c(.025,.975))
dquant2<-quantile(rr2,p=c(.025,.975))




##########################################################################

act_subset <- which(all_data$HOST=="UP" & all_data$exposure=="Unexposed")

data <- cbind(logit(all_data$resistance[act_subset]-0.001), log(all_data$r[act_subset]))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2


# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

rr<-extract(samples)$r
d<-density(rr)


# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

###################################################################

act_subset <- which(all_data$HOST=="UP" & all_data$exposure=="Exposed")

data <- cbind(logit(all_data$resistance[act_subset]-0.001), log(all_data$r[act_subset]))

###################################################################
# bayesian correlation analysis
samples <- stan(model_code=model_simple,   
                data=list(x_obs=data, n = dim(data)[1]), 
                init=list(list(r=0, mu=c(0, 0), lambda=c(1, 1))),  # If not specified, gives random inits
                pars= c("r", "mu", "sigma"),
                iter=10000,
                warmup = 2000,
                chains=1,
                seed=1
)

# output
samples
#plot(samples)
#traceplot(samples)

# calculate median vcoc matrix
act_cov <- extract(samples)$r * extract(samples)$sigma[,1] * extract(samples)$sigma[,2]
est_cov_mat <- matrix(rep(median(act_cov),4),2,2)
diag(est_cov_mat) <- c(median(extract(samples)$sigma[,1])^2, median(extract(samples)$sigma[,2])^2) # here we need variance i.e. sigma^2


# get medians
ctr    <- c(median(extract(samples)$mu[,1]), median(extract(samples)$mu[,2]))

# get median eigenvectors
#eigVec  <- eigen(est_cov_mat)$vectors

# get eigenvector slope posterior distribution
#slope_i <- function(i){
#  est_cov_mat <- matrix(rep(act_cov[i],4),2,2)
#  diag(est_cov_mat) <- c(extract(samples)$sigma[i,1]^2, extract(samples)$sigma[i,2]^2)
#  return(eigen(est_cov_mat)$vectors[2,1]/eigen(est_cov_mat)$vectors[1,1])
#}

#eigen_slope_post <- sapply(1:dim(samples)[1], slope_i)

# run regression model for comparison
#lin_reg_model <- lm(data[,2]~data[,1])

# extract slope distribution from linear model
#lin_post_samples <- rmvnorm(8000, mean=lin_reg_model$coefficients,sigma=vcov(lin_reg_model))

###################################################################

rr2<-extract(samples)$r
d2<-density(rr2)
mean(rr)
mean(rr2)
dquant<-quantile(rr,p=c(.025,.975))
dquant2<-quantile(rr2,p=c(.025,.975))



###################################





