
rm(list=ls())


library(lme4)
library(broom)
library(tidystats)
library(bestNormalize)
library(lme4)
library(car)
library(lme4)
library(mvtnorm)
library(AICcmodavg)
library(binom)
library(Hmisc)
library(lme4)
library(car)
library(readxl)
library(scales)
library(emmeans)
library(arm)
library(QGglmm)
library(MCMCglmm)
library(HDInterval)
library(r2glmm)
library(dispmod)
library(coda)
library(rstan)
library(rethinking)
library(finalfit)
library(dplyr)
library(mice)
library(writexl)
library(brms)
library(loo)

ggbiplot2<-function (pcobj, choices = 1:2, scale = 1, pc.biplot = TRUE, 
                     obs.scale = 1 - scale, var.scale = scale, groups = NULL, 
                     ellipse = FALSE, ellipse.prob = 0.68, labels = NULL, labels.size = 3, 
                     alpha = 1, var.axes = TRUE, circle = FALSE, circle.prob = 0.69, 
                     varname.size = 3, varname.adjust = 1.5, varname.abbrev = FALSE, 
                     ...) 
{
  library(ggplot2)
  library(plyr)
  library(scales)
  library(grid)
  stopifnot(length(choices) == 2)
  if (inherits(pcobj, "prcomp")) {
    nobs.factor <- sqrt(nrow(pcobj$x) - 1)
    d <- pcobj$sdev
    u <- sweep(pcobj$x, 2, 1/(d * nobs.factor), FUN = "*")
    v <- pcobj$rotation
  }
  else if (inherits(pcobj, "princomp")) {
    nobs.factor <- sqrt(pcobj$n.obs)
    d <- pcobj$sdev
    u <- sweep(pcobj$scores, 2, 1/(d * nobs.factor), FUN = "*")
    v <- pcobj$loadings
  }
  else if (inherits(pcobj, "PCA")) {
    nobs.factor <- sqrt(nrow(pcobj$call$X))
    d <- unlist(sqrt(pcobj$eig)[1])
    u <- sweep(pcobj$ind$coord, 2, 1/(d * nobs.factor), FUN = "*")
    v <- sweep(pcobj$var$coord, 2, sqrt(pcobj$eig[1:ncol(pcobj$var$coord), 
                                                  1]), FUN = "/")
  }
  else if (inherits(pcobj, "lda")) {
    nobs.factor <- sqrt(pcobj$N)
    d <- pcobj$svd
    u <- predict(pcobj)$x/nobs.factor
    v <- pcobj$scaling
    d.total <- sum(d^2)
  }
  else {
    stop("Expected a object of class prcomp, princomp, PCA, or lda")
  }
  choices <- pmin(choices, ncol(u))
  df.u <- as.data.frame(sweep(u[, choices], 2, d[choices]^obs.scale, 
                              FUN = "*"))
  v <- sweep(v, 2, d^var.scale, FUN = "*")
  df.v <- as.data.frame(v[, choices])
  names(df.u) <- c("xvar", "yvar")
  names(df.v) <- names(df.u)
  if (pc.biplot) {
    df.u <- df.u * nobs.factor
  }
  r <- sqrt(qchisq(circle.prob, df = 2)) * prod(colMeans(df.u^2))^(1/4)
  v.scale <- rowSums(v^2)
  df.v <- r * df.v/sqrt(max(v.scale))
  if (obs.scale == 0) {
    u.axis.labs <- paste("standardized PC", choices, 
                         sep = "")
  }
  else {
    u.axis.labs <- paste("PC", choices, sep = "")
  }
  u.axis.labs <- paste(u.axis.labs, sprintf("(%0.1f%% explained var.)", 
                                            100 * pcobj$sdev[choices]^2/sum(pcobj$sdev^2)))
  if (!is.null(labels)) {
    df.u$labels <- labels
  }
  if (!is.null(groups)) {
    df.u$groups <- groups
  }
  if (varname.abbrev) {
    df.v$varname <- abbreviate(rownames(v))
  }
  else {
    df.v$varname <- rownames(v)
  }
  df.v$angle <- with(df.v, (180/pi) * atan(yvar/xvar))
  df.v$hjust = with(df.v, (1 - varname.adjust * sign(xvar))/2)
  g <- ggplot(data = df.u, aes(x = xvar, y = yvar)) + xlab(u.axis.labs[1]) + 
    ylab(u.axis.labs[2]) + coord_equal()
  if (var.axes) {
    if (circle) {
      theta <- c(seq(-pi, pi, length = 50), seq(pi, -pi, 
                                                length = 50))
      circle <- data.frame(xvar = r * cos(theta), yvar = r * 
                             sin(theta))
      g <- g + geom_path(data = circle, color = "black", 
                         size = 1/2, alpha = 1/3)
    }
    g <- g + geom_segment(data = df.v, aes(x = 0, y = 0, 
                                           xend = xvar, yend = yvar), arrow = arrow(length = unit(1/2, 
                                                                                                  "picas")), color = "black",size=.8)
  }
  if (!is.null(df.u$labels)) {
    if (!is.null(df.u$groups)) {
      g <- g + geom_text(aes(label = labels, color = groups), 
                         size = labels.size)
    }
    else {
      g <- g + geom_text(aes(label = labels), size = labels.size)
    }
  }
  else {
    if (!is.null(df.u$groups)) {
      g <- g + geom_point(aes(color = groups), alpha = alpha)
    }
    else {
      g <- g + geom_point(alpha = alpha)
    }
  }
  if (!is.null(df.u$groups) && ellipse) {
    theta <- c(seq(-pi, pi, length = 50), seq(pi, -pi, length = 50))
    circle <- cbind(cos(theta), sin(theta))
    ell <- ddply(df.u, "groups", function(x) {
      if (nrow(x) <= 2) {
        return(NULL)
      }
      sigma <- var(cbind(x$xvar, x$yvar))
      mu <- c(mean(x$xvar), mean(x$yvar))
      ed <- sqrt(qchisq(ellipse.prob, df = 2))
      data.frame(sweep(circle %*% chol(sigma) * ed, 2, 
                       mu, FUN = "+"), groups = x$groups[1])
    })
    names(ell)[1:2] <- c("xvar", "yvar")
    g <- g + geom_path(data = ell, aes(color = groups, group = groups),size=1.2)
  }
  if (var.axes) {
    g <- g + geom_text(data = df.v, aes(label = varname, 
                                        x = xvar, y = yvar, angle = angle, hjust = hjust), 
                       color = "black", size = varname.size)
  }
  return(g)
}

options(mc.cores = parallel::detectCores())
rstan_options(auto_write = TRUE)


######## DATA IMPUTATION to obatain IMPUTED DATASET

#df<-read.table(file="Trav_data_NAs.txt", header= TRUE,sep = "\t")
#imp <- mice(df[,5:10], m = 1000, print = FALSE, seed=50)
#N_imp<-apply(imp$imp$N,1,mean)
#tort_imp<-apply(imp$imp$tortuosity,1,mean)
#r_imp<-apply(imp$imp$r,1,mean)
#speed_imp<-apply(imp$imp$speed,1,mean)


###### IMPUTED DATASET

df<-read.table(file="Trav_data_IMPUTED.txt", header= TRUE,sep = "\t")

df$mother_tube<-as.factor(df$mother_tube)
df$rep<-as.factor(df$rep)
df$HOST<-as.factor(df$HOST)
df$exposure<-as.factor(df$exposure)
df$dispersal<-standardize(df$dispersal)
df$resistance<-standardize(df$resistance)
df$N<-standardize(df$N)
df$r<-standardize(df$r)
df$tortuosity<-standardize(df$tortuosity)
df$speed<-standardize(df$speed)


Y_imp<-as.matrix(df[,-c(1:4, 11:16)])


############################################################
#### 2) Run PCA 
############################################################

pca.IMP.all <- prcomp(Y_imp,center = TRUE,scale. = TRUE)
summary(pca.IMP.all)

# Eigenvalues
eig <- (pca.IMP.all$sdev)^2

pca.IMP.all$rotation

ggbiplot2(pca.IMP.all,ellipse=F,alpha=0,
          groups=interaction(df$exposure,df$HOST),circle=F,
          var.axes = T,varname.size=5,varname.adjust=1)+
  theme_bw()+  
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  
  geom_vline(xintercept=c(0,0), linetype="dashed", colour="black",alpha=0.4)+
  geom_hline(yintercept=c(0,0), linetype="dashed", colour="black",alpha=0.4)+
  geom_point(size = 4, stroke = 1.5, shape =c(rep(16,39),rep(1,24)) , 
             colour=c(rep("red",20),rep("blue",19),rep("red",12),rep("blue",12)))+
  theme(legend.position = "bottom")+
  coord_cartesian(xlim = c(-2.7, 2.7), ylim = c(-3, 3))+
  scale_color_manual(name="",labels = c("Core", "Core-Parasite","Front", "Front-Parasite"),values = c("blue", "blue","red", "red"))




#######################################################################
#### Multivariate models with brms
#######################################################################

fit_0 <- brm(
  mvbind(dispersal, resistance, N  , r  , tortuosity  , speed  ) ~ 1 + (1|p|mother_tube),
  data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
  control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
  seed = 1
)
summary(fit_0)

fit_host <- brm(
  mvbind(dispersal, resistance, N  , r  , tortuosity  , speed  ) ~ HOST  + (1|p|mother_tube),
  data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
  control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
  seed = 1
)
summary(fit_host)


fit_exposure <- brm(
  mvbind(dispersal, resistance, N  , r  , tortuosity  , speed  ) ~ exposure + (1|p|mother_tube),
  data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
  control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
  seed = 1
)
summary(fit_exposure)


fit_additive <- brm(
  mvbind(dispersal, resistance, N  , r  , tortuosity  , speed  ) ~ HOST + exposure + (1|p|mother_tube),
  data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
  control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
  seed = 1
)
summary(fit_additive)



fit_interaction <- brm(
  mvbind(dispersal, resistance, N  , r  , tortuosity  , speed  ) ~ HOST * exposure + (1|p|mother_tube),
  data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
  control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
  seed = 1
)
summary(fit_interaction)


fit_intercept <- add_criterion(fit_0, "loo")
fit_E <- add_criterion(fit_exposure, "loo")
fit_H <- add_criterion(fit_host, "loo")
fit_add <- add_criterion(fit_additive, "loo")
fit_raction <- add_criterion(fit_interaction, "loo")

loo(fit_intercept, fit_E, fit_H, fit_add, fit_raction)

w1<-waic(fit_intercept)
w2<-waic(fit_E)
w3<-waic(fit_H)
w4<-waic(fit_add)
w5<-waic(fit_raction)

waics <- c(
  w1$estimates["elpd_waic", 1],
  w2$estimates["elpd_waic", 1],
  w3$estimates["elpd_waic", 1],
  w4$estimates["elpd_waic", 1],
  w5$estimates["elpd_waic", 1]
)


waic_wts <- exp(waics) / sum(exp(waics))
round(cbind( waic_wts), 2)



#############################################
############# Model Averaging Multivariate
#############################################

####DISPERSAL
#summary(fit_raction)
samples_raction <- posterior_samples(fit_raction)

disp_int_core_no <-samples_raction$b_dispersal_Intercept + samples_raction$b_dispersal_exposureUnexposed
disp_int_front_no <-samples_raction$b_dispersal_Intercept + samples_raction$b_dispersal_HOSTUP + samples_raction$b_dispersal_exposureUnexposed + samples_raction$`b_dispersal_HOSTUP:exposureUnexposed` 
disp_int_core_yes <- samples_raction$b_dispersal_Intercept
disp_int_front_yes <- samples_raction$b_dispersal_Intercept + samples_raction$b_dispersal_HOSTUP

disp.model5<-cbind(disp_int_core_no,disp_int_front_no,disp_int_core_yes,disp_int_front_yes)
disp.mean_raction<-apply(disp.model5, 2,mean)


#summary(fit_add)
samples_add <- posterior_samples(fit_add)

disp_add_core_no <-samples_add$b_dispersal_Intercept + samples_add$b_dispersal_exposureUnexposed
disp_add_front_no <-samples_add$b_dispersal_Intercept + samples_add$b_dispersal_exposureUnexposed + samples_add$b_dispersal_HOSTUP
disp_add_core_yes <- samples_add$b_dispersal_Intercept 
disp_add_front_yes <- samples_add$b_dispersal_Intercept + samples_add$b_dispersal_HOSTUP

disp.model4<-cbind(disp_add_core_no,disp_add_front_no,disp_add_core_yes,disp_add_front_yes)
disp.mean_add<-apply(disp.model4,2,mean)



#summary(fit_H)
samples_H <- posterior_samples(fit_H)

disp_H_core_no <-samples_H$b_dispersal_Intercept 
disp_H_front_no <-samples_H$b_dispersal_Intercept  + samples_H$b_dispersal_HOSTUP
disp_H_core_yes <- samples_H$b_dispersal_Intercept 
disp_H_front_yes <- samples_H$b_dispersal_Intercept + samples_H$b_dispersal_HOSTUP

disp.model3<-cbind(disp_H_core_no,disp_H_front_no,disp_H_core_yes,disp_H_front_yes)
disp.mean_H<-apply(disp.model3,2,mean)


length(disp_add_core_no)*0.55
length(disp_add_core_no)*0.22
length(disp_add_core_no)*0.23


set.seed(17)
x<-list()
for (i in colnames(disp.model5))
{
  x[[i]] <-sample(disp.model5[,i], 31350, replace=F)
}
m5<-as.data.frame(x)


set.seed(17)
x<-list()
for (i in colnames(disp.model4))
{
  x[[i]] <-sample(disp.model4[,i], 12540, replace=F)
}
m4<-as.data.frame(x)


set.seed(17)
x<-list()
for (i in colnames(disp.model3))
{
  x[[i]] <-sample(disp.model3[,i], 13110, replace=F)
}
m3<-as.data.frame(x)

colnames(m5) <- c("A","B","C","D")
colnames(m4) <- c("A","B","C","D")
colnames(m3) <- c("A","B","C","D")

mfinal<-rbind(m5,m4,m3)
av.pred.mean<-apply(mfinal,2,mean)


ci<-list()
for (i in colnames(mfinal))
{
  ci[[i]] <-quantile(mfinal[,i],p=c(.025,.975))
}
ci2<-as.data.frame(ci)




####RESISTANCE
#summary(fit_raction)
disp_int_core_no <-samples_raction$b_resistance_Intercept + samples_raction$b_resistance_exposureUnexposed
disp_int_front_no <-samples_raction$b_resistance_Intercept + samples_raction$b_resistance_HOSTUP + samples_raction$b_resistance_exposureUnexposed + samples_raction$`b_resistance_HOSTUP:exposureUnexposed` 
disp_int_core_yes <- samples_raction$b_resistance_Intercept
disp_int_front_yes <- samples_raction$b_resistance_Intercept + samples_raction$b_resistance_HOSTUP

disp.model5<-cbind(disp_int_core_no,disp_int_front_no,disp_int_core_yes,disp_int_front_yes)
disp.mean_raction<-apply(disp.model5, 2,mean)


#summary(fit_add)
disp_add_core_no <-samples_add$b_resistance_Intercept + samples_add$b_resistance_exposureUnexposed
disp_add_front_no <-samples_add$b_resistance_Intercept + samples_add$b_resistance_exposureUnexposed + samples_add$b_resistance_HOSTUP
disp_add_core_yes <- samples_add$b_resistance_Intercept 
disp_add_front_yes <- samples_add$b_resistance_Intercept + samples_add$b_resistance_HOSTUP

disp.model4<-cbind(disp_add_core_no,disp_add_front_no,disp_add_core_yes,disp_add_front_yes)
disp.mean_add<-apply(disp.model4,2,mean)


#summary(fit_H)
disp_H_core_no <-samples_H$b_resistance_Intercept 
disp_H_front_no <-samples_H$b_resistance_Intercept  + samples_H$b_resistance_HOSTUP
disp_H_core_yes <- samples_H$b_resistance_Intercept 
disp_H_front_yes <- samples_H$b_resistance_Intercept + samples_H$b_resistance_HOSTUP

disp.model3<-cbind(disp_H_core_no,disp_H_front_no,disp_H_core_yes,disp_H_front_yes)
disp.mean_H<-apply(disp.model3,2,mean)


set.seed(17)
x<-list()
for (i in colnames(disp.model5))
{
  x[[i]] <-sample(disp.model5[,i], 31350, replace=F)
}
m5<-as.data.frame(x)


set.seed(17)
x<-list()
for (i in colnames(disp.model4))
{
  x[[i]] <-sample(disp.model4[,i], 12540, replace=F)
}
m4<-as.data.frame(x)


set.seed(17)
x<-list()
for (i in colnames(disp.model3))
{
  x[[i]] <-sample(disp.model3[,i], 13110, replace=F)
}
m3<-as.data.frame(x)

colnames(m5) <- c("A","B","C","D")
colnames(m4) <- c("A","B","C","D")
colnames(m3) <- c("A","B","C","D")

mfinal<-rbind(m5,m4,m3)
av.pred.mean<-apply(mfinal,2,mean)


ci<-list()
for (i in colnames(mfinal))
{
  ci[[i]] <-quantile(mfinal[,i],p=c(.025,.975))
}
ci2<-as.data.frame(ci)



#### r
#summary(fit_raction)
disp_int_core_no <-samples_raction$b_r_Intercept + samples_raction$b_r_exposureUnexposed
disp_int_front_no <-samples_raction$b_r_Intercept + samples_raction$b_r_HOSTUP + samples_raction$b_r_exposureUnexposed + samples_raction$`b_r_HOSTUP:exposureUnexposed` 
disp_int_core_yes <- samples_raction$b_r_Intercept
disp_int_front_yes <- samples_raction$b_r_Intercept + samples_raction$b_r_HOSTUP

disp.model5<-cbind(disp_int_core_no,disp_int_front_no,disp_int_core_yes,disp_int_front_yes)
disp.mean_raction<-apply(disp.model5, 2,mean)



#summary(fit_add)
disp_add_core_no <-samples_add$b_r_Intercept + samples_add$b_r_exposureUnexposed
disp_add_front_no <-samples_add$b_r_Intercept + samples_add$b_r_exposureUnexposed + samples_add$b_r_HOSTUP
disp_add_core_yes <- samples_add$b_r_Intercept 
disp_add_front_yes <- samples_add$b_r_Intercept + samples_add$b_r_HOSTUP

disp.model4<-cbind(disp_add_core_no,disp_add_front_no,disp_add_core_yes,disp_add_front_yes)
disp.mean_add<-apply(disp.model4,2,mean)



#summary(fit_H)
disp_H_core_no <-samples_H$b_r_Intercept 
disp_H_front_no <-samples_H$b_r_Intercept  + samples_H$b_r_HOSTUP
disp_H_core_yes <- samples_H$b_r_Intercept 
disp_H_front_yes <- samples_H$b_r_Intercept + samples_H$b_r_HOSTUP

disp.model3<-cbind(disp_H_core_no,disp_H_front_no,disp_H_core_yes,disp_H_front_yes)
disp.mean_H<-apply(disp.model3,2,mean)


set.seed(17)
x<-list()
for (i in colnames(disp.model5))
{
  x[[i]] <-sample(disp.model5[,i], 31350, replace=F)
}
m5<-as.data.frame(x)


set.seed(17)
x<-list()
for (i in colnames(disp.model4))
{
  x[[i]] <-sample(disp.model4[,i], 12540, replace=F)
}
m4<-as.data.frame(x)


set.seed(17)
x<-list()
for (i in colnames(disp.model3))
{
  x[[i]] <-sample(disp.model3[,i], 13110, replace=F)
}
m3<-as.data.frame(x)

colnames(m5) <- c("A","B","C","D")
colnames(m4) <- c("A","B","C","D")
colnames(m3) <- c("A","B","C","D")

mfinal<-rbind(m5,m4,m3)
av.pred.mean<-apply(mfinal,2,mean)


ci<-list()
for (i in colnames(mfinal))
{
  ci[[i]] <-quantile(mfinal[,i],p=c(.025,.975))
}
ci2<-as.data.frame(ci)





#### N
#summary(fit_raction)
disp_int_core_no <-samples_raction$b_N_Intercept + samples_raction$b_N_exposureUnexposed
disp_int_front_no <-samples_raction$b_N_Intercept + samples_raction$b_N_HOSTUP + samples_raction$b_N_exposureUnexposed + samples_raction$`b_N_HOSTUP:exposureUnexposed` 
disp_int_core_yes <- samples_raction$b_N_Intercept
disp_int_front_yes <- samples_raction$b_N_Intercept + samples_raction$b_N_HOSTUP

disp.model5<-cbind(disp_int_core_no,disp_int_front_no,disp_int_core_yes,disp_int_front_yes)
disp.mean_raction<-apply(disp.model5, 2,mean)



#summary(fit_add)
disp_add_core_no <-samples_add$b_N_Intercept + samples_add$b_N_exposureUnexposed
disp_add_front_no <-samples_add$b_N_Intercept + samples_add$b_N_exposureUnexposed + samples_add$b_N_HOSTUP
disp_add_core_yes <- samples_add$b_N_Intercept 
disp_add_front_yes <- samples_add$b_N_Intercept + samples_add$b_N_HOSTUP

disp.model4<-cbind(disp_add_core_no,disp_add_front_no,disp_add_core_yes,disp_add_front_yes)
disp.mean_add<-apply(disp.model4,2,mean)



#summary(fit_H)
disp_H_core_no <-samples_H$b_N_Intercept 
disp_H_front_no <-samples_H$b_N_Intercept  + samples_H$b_N_HOSTUP
disp_H_core_yes <- samples_H$b_N_Intercept 
disp_H_front_yes <- samples_H$b_N_Intercept + samples_H$b_N_HOSTUP

disp.model3<-cbind(disp_H_core_no,disp_H_front_no,disp_H_core_yes,disp_H_front_yes)
disp.mean_H<-apply(disp.model3,2,mean)


set.seed(17)
x<-list()
for (i in colnames(disp.model5))
{
  x[[i]] <-sample(disp.model5[,i], 31350, replace=F)
}
m5<-as.data.frame(x)


set.seed(17)
x<-list()
for (i in colnames(disp.model4))
{
  x[[i]] <-sample(disp.model4[,i], 12540, replace=F)
}
m4<-as.data.frame(x)


set.seed(17)
x<-list()
for (i in colnames(disp.model3))
{
  x[[i]] <-sample(disp.model3[,i], 13110, replace=F)
}
m3<-as.data.frame(x)

colnames(m5) <- c("A","B","C","D")
colnames(m4) <- c("A","B","C","D")
colnames(m3) <- c("A","B","C","D")

mfinal<-rbind(m5,m4,m3)
av.pred.mean<-apply(mfinal,2,mean)


ci<-list()
for (i in colnames(mfinal))
{
  ci[[i]] <-quantile(mfinal[,i],p=c(.025,.975))
}
ci2<-as.data.frame(ci)



#### SPEED
#summary(fit_raction)
disp_int_core_no <-samples_raction$b_speed_Intercept + samples_raction$b_speed_exposureUnexposed
disp_int_front_no <-samples_raction$b_speed_Intercept + samples_raction$b_speed_HOSTUP + samples_raction$b_speed_exposureUnexposed + samples_raction$`b_speed_HOSTUP:exposureUnexposed` 
disp_int_core_yes <- samples_raction$b_speed_Intercept
disp_int_front_yes <- samples_raction$b_speed_Intercept + samples_raction$b_speed_HOSTUP

disp.model5<-cbind(disp_int_core_no,disp_int_front_no,disp_int_core_yes,disp_int_front_yes)
disp.mean_raction<-apply(disp.model5, 2,mean)



#summary(fit_add)
disp_add_core_no <-samples_add$b_speed_Intercept + samples_add$b_speed_exposureUnexposed
disp_add_front_no <-samples_add$b_speed_Intercept + samples_add$b_speed_exposureUnexposed + samples_add$b_speed_HOSTUP
disp_add_core_yes <- samples_add$b_speed_Intercept 
disp_add_front_yes <- samples_add$b_speed_Intercept + samples_add$b_speed_HOSTUP

disp.model4<-cbind(disp_add_core_no,disp_add_front_no,disp_add_core_yes,disp_add_front_yes)
disp.mean_add<-apply(disp.model4,2,mean)


#summary(fit_H)
disp_H_core_no <-samples_H$b_speed_Intercept 
disp_H_front_no <-samples_H$b_speed_Intercept  + samples_H$b_speed_HOSTUP
disp_H_core_yes <- samples_H$b_speed_Intercept 
disp_H_front_yes <- samples_H$b_speed_Intercept + samples_H$b_speed_HOSTUP

disp.model3<-cbind(disp_H_core_no,disp_H_front_no,disp_H_core_yes,disp_H_front_yes)
disp.mean_H<-apply(disp.model3,2,mean)


set.seed(17)
x<-list()
for (i in colnames(disp.model5))
{
  x[[i]] <-sample(disp.model5[,i], 31350, replace=F)
}
m5<-as.data.frame(x)


set.seed(17)
x<-list()
for (i in colnames(disp.model4))
{
  x[[i]] <-sample(disp.model4[,i], 12540, replace=F)
}
m4<-as.data.frame(x)


set.seed(17)
x<-list()
for (i in colnames(disp.model3))
{
  x[[i]] <-sample(disp.model3[,i], 13110, replace=F)
}
m3<-as.data.frame(x)

colnames(m5) <- c("A","B","C","D")
colnames(m4) <- c("A","B","C","D")
colnames(m3) <- c("A","B","C","D")

mfinal<-rbind(m5,m4,m3)
av.pred.mean<-apply(mfinal,2,mean)


ci<-list()
for (i in colnames(mfinal))
{
  ci[[i]] <-quantile(mfinal[,i],p=c(.025,.975))
}
ci2<-as.data.frame(ci)


#### TORTUOSITY
#summary(fit_raction)
disp_int_core_no <-samples_raction$b_tortuosity_Intercept + samples_raction$b_tortuosity_exposureUnexposed
disp_int_front_no <-samples_raction$b_tortuosity_Intercept + samples_raction$b_tortuosity_HOSTUP + samples_raction$b_tortuosity_exposureUnexposed + samples_raction$`b_tortuosity_HOSTUP:exposureUnexposed` 
disp_int_core_yes <- samples_raction$b_tortuosity_Intercept
disp_int_front_yes <- samples_raction$b_tortuosity_Intercept + samples_raction$b_tortuosity_HOSTUP

disp.model5<-cbind(disp_int_core_no,disp_int_front_no,disp_int_core_yes,disp_int_front_yes)
disp.mean_raction<-apply(disp.model5, 2,mean)


#summary(fit_add)
disp_add_core_no <-samples_add$b_tortuosity_Intercept + samples_add$b_tortuosity_exposureUnexposed
disp_add_front_no <-samples_add$b_tortuosity_Intercept + samples_add$b_tortuosity_exposureUnexposed + samples_add$b_tortuosity_HOSTUP
disp_add_core_yes <- samples_add$b_tortuosity_Intercept 
disp_add_front_yes <- samples_add$b_tortuosity_Intercept + samples_add$b_tortuosity_HOSTUP

disp.model4<-cbind(disp_add_core_no,disp_add_front_no,disp_add_core_yes,disp_add_front_yes)
disp.mean_add<-apply(disp.model4,2,mean)



#summary(fit_H)
disp_H_core_no <-samples_H$b_tortuosity_Intercept 
disp_H_front_no <-samples_H$b_tortuosity_Intercept  + samples_H$b_tortuosity_HOSTUP
disp_H_core_yes <- samples_H$b_tortuosity_Intercept 
disp_H_front_yes <- samples_H$b_tortuosity_Intercept + samples_H$b_tortuosity_HOSTUP

disp.model3<-cbind(disp_H_core_no,disp_H_front_no,disp_H_core_yes,disp_H_front_yes)
disp.mean_H<-apply(disp.model3,2,mean)


set.seed(17)
x<-list()
for (i in colnames(disp.model5))
{
  x[[i]] <-sample(disp.model5[,i], 31350, replace=F)
}
m5<-as.data.frame(x)


set.seed(17)
x<-list()
for (i in colnames(disp.model4))
{
  x[[i]] <-sample(disp.model4[,i], 12540, replace=F)
}
m4<-as.data.frame(x)


set.seed(17)
x<-list()
for (i in colnames(disp.model3))
{
  x[[i]] <-sample(disp.model3[,i], 13110, replace=F)
}
m3<-as.data.frame(x)

colnames(m5) <- c("A","B","C","D")
colnames(m4) <- c("A","B","C","D")
colnames(m3) <- c("A","B","C","D")

mfinal<-rbind(m5,m4,m3)
av.pred.mean<-apply(mfinal,2,mean)


ci<-list()
for (i in colnames(mfinal))
{
  ci[[i]] <-quantile(mfinal[,i],p=c(.025,.975))
}
ci2<-as.data.frame(ci)







#######################################################################
#### Univariate models with brms
#######################################################################

df<-read.table(file="Proc_B_IMPUTED_ONDATA.txt", header= TRUE,sep = "\t")

df$mother_tube<-as.factor(df$mother_tube)
df$rep<-as.factor(df$rep)
df$HOST<-as.factor(df$HOST)
df$exposure<-as.factor(df$exposure)
df$dispersal<-standardize(df$dispersal)
df$resistance<-standardize(df$resistance)
df$N<-standardize(df$N)
df$r<-standardize(df$r)
df$tortuosity<-standardize(df$tortuosity)
df$speed<-standardize(df$speed)



######### DISPERSAL
fit_0 <- brm(dispersal ~ 1 + (1|p|mother_tube),
             data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
             control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
             seed = 1
)
summary(fit_0)


fit_host <- brm(dispersal ~ HOST  + (1|p|mother_tube),
                data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                seed = 1
)
summary(fit_host)



fit_exposure <- brm(dispersal ~ exposure + (1|p|mother_tube),
                    data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                    control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                    seed = 1
)
summary(fit_exposure)


fit_additive <- brm(dispersal ~ HOST + exposure + (1|p|mother_tube),
                    data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                    control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                    seed = 1
)
summary(fit_additive)



fit_interaction <- brm(dispersal ~ HOST * exposure + (1|p|mother_tube),
                       data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                       control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                       seed = 1
)
summary(fit_interaction)


fit_intercept <- add_criterion(fit_0, "loo")
fit_E <- add_criterion(fit_exposure, "loo")
fit_H <- add_criterion(fit_host, "loo")
fit_add <- add_criterion(fit_additive, "loo")
fit_raction <- add_criterion(fit_interaction, "loo")

loo(fit_intercept, fit_E, fit_H, fit_add, fit_raction)

w1<-waic(fit_intercept)
w2<-waic(fit_E)
w3<-waic(fit_H)
w4<-waic(fit_add)
w5<-waic(fit_raction)

waics <- c(
  w1$estimates["elpd_waic", 1],
  w2$estimates["elpd_waic", 1],
  w3$estimates["elpd_waic", 1],
  w4$estimates["elpd_waic", 1],
  w5$estimates["elpd_waic", 1]
)


waic_wts <- exp(waics) / sum(exp(waics))
round(cbind( waic_wts), 2)



######### RESISTANCE
fit_0 <- brm(resistance ~ 1 + (1|p|mother_tube),
             data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
             control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
             seed = 1
)
summary(fit_0)


fit_host <- brm(resistance ~ HOST  + (1|p|mother_tube),
                data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                seed = 1
)
summary(fit_host)


fit_exposure <- brm(resistance ~ exposure + (1|p|mother_tube),
                    data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                    control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                    seed = 1
)
summary(fit_exposure)


fit_additive <- brm(resistance ~ HOST + exposure + (1|p|mother_tube),
                    data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                    control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                    seed = 1
)
summary(fit_additive)


fit_interaction <- brm(resistance ~ HOST * exposure + (1|p|mother_tube),
                       data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                       control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                       seed = 1
)
summary(fit_interaction)


fit_intercept <- add_criterion(fit_0, "loo")
fit_E <- add_criterion(fit_exposure, "loo")
fit_H <- add_criterion(fit_host, "loo")
fit_add <- add_criterion(fit_additive, "loo")
fit_raction <- add_criterion(fit_interaction, "loo")

loo(fit_intercept, fit_E, fit_H, fit_add, fit_raction)

w1<-waic(fit_intercept)
w2<-waic(fit_E)
w3<-waic(fit_H)
w4<-waic(fit_add)
w5<-waic(fit_raction)

waics <- c(
  w1$estimates["elpd_waic", 1],
  w2$estimates["elpd_waic", 1],
  w3$estimates["elpd_waic", 1],
  w4$estimates["elpd_waic", 1],
  w5$estimates["elpd_waic", 1]
)


waic_wts <- exp(waics) / sum(exp(waics))
round(cbind( waic_wts), 2)



######### speed
fit_0 <- brm(speed ~ 1 + (1|p|mother_tube),
             data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
             control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
             seed = 1
)
summary(fit_0)


fit_host <- brm(speed ~ HOST  + (1|p|mother_tube),
                data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                seed = 1
)
summary(fit_host)


fit_exposure <- brm(speed ~ exposure + (1|p|mother_tube),
                    data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                    control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                    seed = 1
)
summary(fit_exposure)

fit_additive <- brm(speed ~ HOST + exposure + (1|p|mother_tube),
                    data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                    control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                    seed = 1
)
summary(fit_additive)


fit_interaction <- brm(speed ~ HOST * exposure + (1|p|mother_tube),
                       data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                       control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                       seed = 1
)
summary(fit_interaction)


fit_intercept <- add_criterion(fit_0, "loo")
fit_E <- add_criterion(fit_exposure, "loo")
fit_H <- add_criterion(fit_host, "loo")
fit_add <- add_criterion(fit_additive, "loo")
fit_raction <- add_criterion(fit_interaction, "loo")

loo(fit_intercept, fit_E, fit_H, fit_add, fit_raction)

w1<-waic(fit_intercept)
w2<-waic(fit_E)
w3<-waic(fit_H)
w4<-waic(fit_add)
w5<-waic(fit_raction)

waics <- c(
  w1$estimates["elpd_waic", 1],
  w2$estimates["elpd_waic", 1],
  w3$estimates["elpd_waic", 1],
  w4$estimates["elpd_waic", 1],
  w5$estimates["elpd_waic", 1]
)

waic_wts <- exp(waics) / sum(exp(waics))
round(cbind( waic_wts), 2)



######### tortuosity
fit_0 <- brm(tortuosity ~ 1 + (1|p|mother_tube),
             data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
             control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
             seed = 1
)
summary(fit_0)


fit_host <- brm(tortuosity ~ HOST  + (1|p|mother_tube),
                data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                seed = 1
)
summary(fit_host)


fit_exposure <- brm(tortuosity ~ exposure + (1|p|mother_tube),
                    data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                    control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                    seed = 1
)
summary(fit_exposure)

fit_additive <- brm(tortuosity ~ HOST + exposure + (1|p|mother_tube),
                    data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                    control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                    seed = 1
)
summary(fit_additive)


fit_interaction <- brm(tortuosity ~ HOST * exposure + (1|p|mother_tube),
                       data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                       control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                       seed = 1
)
summary(fit_interaction)


fit_intercept <- add_criterion(fit_0, "loo")
fit_E <- add_criterion(fit_exposure, "loo")
fit_H <- add_criterion(fit_host, "loo")
fit_add <- add_criterion(fit_additive, "loo")
fit_raction <- add_criterion(fit_interaction, "loo")

loo(fit_intercept, fit_E, fit_H, fit_add, fit_raction)

w1<-waic(fit_intercept)
w2<-waic(fit_E)
w3<-waic(fit_H)
w4<-waic(fit_add)
w5<-waic(fit_raction)

waics <- c(
  w1$estimates["elpd_waic", 1],
  w2$estimates["elpd_waic", 1],
  w3$estimates["elpd_waic", 1],
  w4$estimates["elpd_waic", 1],
  w5$estimates["elpd_waic", 1]
)

waic_wts <- exp(waics) / sum(exp(waics))
round(cbind( waic_wts), 2)



######### r
fit_0 <- brm(r ~ 1 + (1|p|mother_tube),
             data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
             control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
             seed = 1
)
summary(fit_0)


fit_host <- brm(r ~ HOST  + (1|p|mother_tube),
                data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                seed = 1
)
summary(fit_host)



fit_exposure <- brm(r ~ exposure + (1|p|mother_tube),
                    data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                    control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                    seed = 1
)
summary(fit_exposure)


fit_additive <- brm(r ~ HOST + exposure + (1|p|mother_tube),
                    data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                    control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                    seed = 1
)
summary(fit_additive)


fit_interaction <- brm(r ~ HOST * exposure + (1|p|mother_tube),
                       data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                       control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                       seed = 1
)
summary(fit_interaction)


fit_intercept <- add_criterion(fit_0, "loo")
fit_E <- add_criterion(fit_exposure, "loo")
fit_H <- add_criterion(fit_host, "loo")
fit_add <- add_criterion(fit_additive, "loo")
fit_raction <- add_criterion(fit_interaction, "loo")


library(loo)
loo(fit_intercept, fit_E, fit_H, fit_add, fit_raction)

w1<-waic(fit_intercept)
w2<-waic(fit_E)
w3<-waic(fit_H)
w4<-waic(fit_add)
w5<-waic(fit_raction)

waics <- c(
  w1$estimates["elpd_waic", 1],
  w2$estimates["elpd_waic", 1],
  w3$estimates["elpd_waic", 1],
  w4$estimates["elpd_waic", 1],
  w5$estimates["elpd_waic", 1]
)

l1<-loo(fit_intercept)
l2<-loo(fit_E)
l3<-loo(fit_H)
l4<-loo(fit_add)
l5<-loo(fit_raction)

lpd_point <- cbind(
  l1$pointwise[,"elpd_loo"], 
  l2$pointwise[,"elpd_loo"],
  l3$pointwise[,"elpd_loo"], 
  l4$pointwise[,"elpd_loo"],
  l5$pointwise[,"elpd_loo"]
)


waic_wts <- exp(waics) / sum(exp(waics))
round(cbind( waic_wts), 2)




######### N
fit_0 <- brm(N ~ 1 + (1|p|mother_tube),
             data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
             control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
             seed = 1
)
summary(fit_0)


fit_host <- brm(N ~ HOST  + (1|p|mother_tube),
                data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                seed = 1
)
summary(fit_host)


fit_exposure <- brm(N ~ exposure + (1|p|mother_tube),
                    data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                    control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                    seed = 1
)
summary(fit_exposure)


fit_additive <- brm(N ~ HOST + exposure + (1|p|mother_tube),
                    data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                    control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                    seed = 1
)
summary(fit_additive)


fit_interaction <- brm(N ~ HOST * exposure + (1|p|mother_tube),
                       data = df, chains = 3, cores = 4, save_pars = save_pars(all = TRUE),
                       control = list(adapt_delta = .975, max_treedepth = 20),iter = 20000, warmup = 1000,
                       seed = 1
)
summary(fit_interaction)


fit_intercept <- add_criterion(fit_0, "loo")
fit_E <- add_criterion(fit_exposure, "loo")
fit_H <- add_criterion(fit_host, "loo")
fit_add <- add_criterion(fit_additive, "loo")
fit_raction <- add_criterion(fit_interaction, "loo")

loo(fit_intercept, fit_E, fit_H, fit_add, fit_raction)

w1<-waic(fit_intercept)
w2<-waic(fit_E)
w3<-waic(fit_H)
w4<-waic(fit_add)
w5<-waic(fit_raction)

waics <- c(
  w1$estimates["elpd_waic", 1],
  w2$estimates["elpd_waic", 1],
  w3$estimates["elpd_waic", 1],
  w4$estimates["elpd_waic", 1],
  w5$estimates["elpd_waic", 1]
)


waic_wts <- exp(waics) / sum(exp(waics))
round(cbind( waic_wts), 2)


